library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(dplyr)
library(magrittr)
library(plotrix)
library(ggplot2)
library(ggridges)
library(viridis)
titel <- "Spectra"
ondertitel1 <- 'Yeast codon optimized FPs' #ondertitel 1
ondertitel2 <- 'From plate'                   #ondertitel2: wat moet er nog na de tekst "x samples" komen?
TextatXaxis <- "Wavelength (nm)"   #which label should the X axis have?
TextatYaxis <- "Normalized absorbance & emission" #which label should the y axis have?

#import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "*.csv")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.csv(x, sep=",", header=T)) 
combined = do.call("smartbind", datalist)

#change column name to wavelength
colnames(combined)[1] <- "wavelength_nm"

#add FP names
library(mosaic)
combined <- mutate(combined, FP_name = derivedFactor(
  "ymTq2" = str_detect(FP, "mt"),
  "ymNeongreen" = str_detect(FP, "mneon"),
  "ymYPET" = str_detect(FP, "ymY"),
  "ytdTomato" = str_detect(FP, "ydt"),
  "ymScarletI" = str_detect(FP, "yms"),
  "ymVenus" = str_detect(FP, "ym"),
  .method = "first",
  .default = 0
))

#change dataframe format and normalize each spectrum
combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean")) #change format of the dataframe 
combined2$Fluorescence[combined2$Fluorescence < 0] <- 0 #change all values below 0 to 0
combined3 <- combined2 %>% group_by(FP, Name)  %>%   mutate(Fluorescence = Fluorescence / max(Fluorescence))
combined3$Fluorescence[is.na(combined3$Fluorescence)] <- 0 #change al NA to 0

#add statistics
combined4 <- combined3 %>% group_by(FP, wavelength_nm, FP_name)  %>%   summarise_at("Fluorescence", funs(mean,sd,std.error))
colnames(combined4)[4] <- "mean_fluorescence"

#add column to define excitation or emission spectrum
library(mosaic)
combined4 <- mutate(combined4, exc_emission = derivedFactor(
  "emission" = str_detect(FP, "emis"),
  "excitation" = str_detect(FP, "exc"),
  .method = "first",
  .default = 0
))

#plot data
plot <- ggplot(data=combined4, aes(x=wavelength_nm, y = mean_fluorescence,  colour=FP, fill=FP))    + geom_ribbon(aes(ymin=0, ymax=mean_fluorescence, fill=FP, alpha = exc_emission))  + scale_alpha_ordinal(range = c( 0.9, 0.5)) + geom_line(aes(linetype =exc_emission), size=1) + scale_color_manual(values=c("black","black","black","black","black","black","black","black","black","black","black","black" )) + scale_fill_manual(values=c("#3EC73E", "#3EC73E", "#dd2c2c", "#dd2c2c", "#168be5", "#168be5", "#FFF000", "#FFF000", "#FFF000", "#FFF000", "#ff6a00", "#ff6a00"))  + theme_bw() + labs(title = titel, subtitle = ondertitel1) + ylab(TextatYaxis) + xlab(TextatXaxis) + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.subtitle = element_text(hjust = 0.5)) + theme(text=element_text(size=23))  +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16),
                                                                                                                                                                                                                                                                                                                                                                                                           axis.text = element_text( size = 15 ),
                                                                                                                                                                                                                                                                                                                                                                                                           axis.text.x = element_text( size = 15 ),
                                                                                                                                                                                                                                                                                                                                                                                                           axis.title = element_text( size = 15),
                                                                                                                                                                                                                                                                                                                                                                                                           plot.title = element_text(size=24),
                                                                                                                                                                                                                                                                                                                                                                                                           plot.subtitle = element_text(size=18),
                                                                                                                                                                                                                                                                                                                                                                                                           legend.position="none") 
plot
plot2 <- plot + facet_wrap(.~FP_name, ncol=3)  + coord_cartesian(xlim = c(340, 700), ylim = c(0.05, 1))
plot2
